@@ -24,7 +24,9 @@ impl<T: GetSizeTracker> GetSizeTracker for Box<T> {
 
 impl<T: GetSizeTracker> GetSizeTracker for Mutex<T> {
     fn track<A>(&mut self, addr: *const A) -> bool {
-        let tracker = self.get_mut().expect("Mutex was poisoned");
+        let tracker = self
+            .get_mut()
+            .unwrap_or_else(std::sync::PoisonError::into_inner);
 
         GetSizeTracker::track(&mut *tracker, addr)
     }
@@ -32,7 +34,9 @@ impl<T: GetSizeTracker> GetSizeTracker for Mutex<T> {
 
 impl<T: GetSizeTracker> GetSizeTracker for RwLock<T> {
     fn track<A>(&mut self, addr: *const A) -> bool {
-        let mut tracker = self.write().expect("RwLock was poisoned");
+        let mut tracker = self
+            .write()
+            .unwrap_or_else(std::sync::PoisonError::into_inner);
 
         GetSizeTracker::track(&mut *tracker, addr)
     }
@@ -40,7 +44,9 @@ impl<T: GetSizeTracker> GetSizeTracker for RwLock<T> {
 
 impl<T: GetSizeTracker> GetSizeTracker for Arc<Mutex<T>> {
     fn track<A>(&mut self, addr: *const A) -> bool {
-        let mut tracker = self.lock().expect("Mutex was poisoned");
+        let mut tracker = self
+            .lock()
+            .unwrap_or_else(std::sync::PoisonError::into_inner);
 
         GetSizeTracker::track(&mut *tracker, addr)
     }
@@ -48,7 +54,9 @@ impl<T: GetSizeTracker> GetSizeTracker for Arc<Mutex<T>> {
 
 impl<T: GetSizeTracker> GetSizeTracker for Arc<RwLock<T>> {
     fn track<A>(&mut self, addr: *const A) -> bool {
-        let mut tracker = self.write().expect("RwLock was poisoned");
+        let mut tracker = self
+            .write()
+            .unwrap_or_else(std::sync::PoisonError::into_inner);
 
         GetSizeTracker::track(&mut *tracker, addr)
     }
@@ -97,7 +105,7 @@ impl NoTracker {
     }
 
     /// Changes the answer which will always be returned by this pseudo tracker.
-    pub fn set_answer(&mut self, answer: bool) {
+    pub const fn set_answer(&mut self, answer: bool) {
         self.answer = answer;
     }
 }
