@@ -1026,49 +1026,67 @@ schema_for_pickfirst!(A B);
 schema_for_pickfirst!(A B C);
 schema_for_pickfirst!(A B C D);
 
-impl<T, TA> JsonSchemaAs<T> for SetLastValueWins<TA>
-where
-    TA: JsonSchemaAs<T>,
-{
-    fn schema_id() -> Cow<'static, str> {
-        std::format!(
-            "serde_with::SetLastValueWins<{}>",
-            <WrapSchema<T, TA> as JsonSchema>::schema_id()
-        )
-        .into()
-    }
+macro_rules! map_first_last_wins_schema {
+    ($(=> $extra:ident)? $type:ty) => {
+        impl<V, $($extra,)? VA> JsonSchemaAs<$type> for SetLastValueWins<VA>
+        where
+            VA: JsonSchemaAs<V>,
+        {
+            fn schema_id() -> Cow<'static, str> {
+                std::format!(
+                    "serde_with::SetLastValueWins<{}>",
+                    <WrapSchema<V, VA> as JsonSchema>::schema_id()
+                )
+                .into()
+            }
 
-    fn schema_name() -> String {
-        std::format!(
-            "SetLastValueWins<{}>",
-            <WrapSchema<T, TA> as JsonSchema>::schema_name()
-        )
-    }
+            fn schema_name() -> String {
+                std::format!(
+                    "SetLastValueWins<{}>",
+                    <WrapSchema<V, VA> as JsonSchema>::schema_name()
+                )
+            }
 
-    fn json_schema(gen: &mut SchemaGenerator) -> Schema {
-        let schema = <WrapSchema<T, TA> as JsonSchema>::json_schema(gen);
-        let mut schema = schema.into_object();
+            fn json_schema(gen: &mut SchemaGenerator) -> Schema {
+                let schema = <BTreeSet<WrapSchema<V, VA>> as JsonSchema>::json_schema(gen);
+                let mut schema = schema.into_object();
 
-        // We explicitly allow duplicate items since the whole point of
-        // SetLastValueWins is to take the duplicate value.
-        if let Some(array) = &mut schema.array {
-            array.unique_items = None;
+                // We explicitly allow duplicate items since the whole point of
+                // SetLastValueWins is to take the duplicate value.
+                if let Some(array) = &mut schema.array {
+                    array.unique_items = None;
+                }
+
+                schema.into()
+            }
+
+            fn is_referenceable() -> bool {
+                false
+            }
         }
 
-        schema.into()
-    }
-
-    fn is_referenceable() -> bool {
-        false
+        impl<V, $($extra,)? VA> JsonSchemaAs<$type> for SetPreventDuplicates<VA>
+        where
+            VA: JsonSchemaAs<V>,
+        {
+            forward_schema!(BTreeSet<WrapSchema<V, VA>>);
+        }
     }
 }
 
-impl<T, TA> JsonSchemaAs<T> for SetPreventDuplicates<TA>
-where
-    TA: JsonSchemaAs<T>,
-{
-    forward_schema!(WrapSchema<T, TA>);
-}
+map_first_last_wins_schema!(BTreeSet<V>);
+#[cfg(feature = "std")]
+map_first_last_wins_schema!(=> S HashSet<V, S>);
+#[cfg(feature = "hashbrown_0_14")]
+map_first_last_wins_schema!(=> S hashbrown_0_14::HashSet<V, S>);
+#[cfg(feature = "hashbrown_0_15")]
+map_first_last_wins_schema!(=> S hashbrown_0_15::HashSet<V, S>);
+#[cfg(feature = "hashbrown_0_16")]
+map_first_last_wins_schema!(=> S hashbrown_0_16::HashSet<V, S>);
+#[cfg(feature = "indexmap_1")]
+map_first_last_wins_schema!(=> S indexmap_1::IndexSet<V, S>);
+#[cfg(feature = "indexmap_2")]
+map_first_last_wins_schema!(=> S indexmap_2::IndexSet<V, S>);
 
 impl<SEP, T, TA> JsonSchemaAs<T> for StringWithSeparator<SEP, TA>
 where
@@ -1310,3 +1328,8 @@ forward_duration_schema!(TimestampSecondsWithFrac);
 forward_duration_schema!(TimestampMilliSecondsWithFrac);
 forward_duration_schema!(TimestampMicroSecondsWithFrac);
 forward_duration_schema!(TimestampNanoSecondsWithFrac);
+
+#[cfg(feature = "json")]
+impl<T> JsonSchemaAs<T> for json::JsonString {
+    forward_schema!(String);
+}
